@@ -1,9 +1,14 @@
 #' Creates high-resolution heatmap of trajectory data.
 #' 
+#' @description 
+#' `r lifecycle::badge("experimental")`
+#' 
 #' \code{mt_heatmap_raw} creates a high-resolution heatmap image of the 
 #' trajectory data using gaussian smoothing. Note that this function has beta
 #' status.
 #' 
+#' @details 
+#' 
 #' To create the image, \code{mt_heatmap_raw} takes the following steps. First, 
 #' the function maps the trajectory points to a pixel space with x ranging from 
 #' 1 to xres and y ranging from 1 to xres divided by the ratio of x and y's 
@@ -426,9 +431,14 @@ mt_heatmap_raw <- function(
 
 #' Plot trajectory heatmap.
 #' 
+#' @description 
+#' `r lifecycle::badge("experimental")`
+#' 
 #' \code{mt_heatmap} plots high resolution raw trajectory maps. Note that this
 #' function has beta status.
 #' 
+#' @details 
+#' 
 #' \code{mt_heatmap} wraps \link{mt_heatmap_raw} and provides direct plotting 
 #' output in \link[grDevices:png]{tiff}, \link[grDevices]{png},
 #' \link[grDevices]{pdf}, or R's default window output. For further details on
@@ -501,7 +511,7 @@ mt_heatmap <- function(
   if(is_mousetrap_data(x) | is.array(x)){
     if(is_mousetrap_data(x)) x = extract_data(data = x, use = use)
     if(!all(dimensions %in% dimnames(x)[[3]])) stop('Not all dimensions found.')
-    heatmap = mt_heatmap_raw(x,use,dimensions,...)
+    heatmap = mt_heatmap_raw(x,use,dimensions,verbose=verbose,...)
     img = heatmap$img
     agg = heatmap$agg
     bg  = heatmap$colors[1]
@@ -605,8 +615,13 @@ mt_heatmap <- function(
 
 #' Plot trajectory heatmap using ggplot.
 #' 
+#' @description 
+#' `r lifecycle::badge("experimental")`
+#' 
 #' \code{mt_heatmap_ggplot} plots high resolution raw trajectory maps. Note that
 #' this function has beta status.
+#' 
+#' @details 
 #'
 #' \code{mt_heatmap_ggplot} wraps \link{mt_heatmap_raw} and returns a ggplot
 #' object containing the plot. In contrast to \code{mt_heatmap_plot} plots
@@ -766,9 +781,14 @@ print.mt_heatmap_raw = function(x,...){
 
 #' Creates a difference-heatmap of two trajectory heatmap images.
 #'
+#' @description 
+#' `r lifecycle::badge("experimental")`
+#' 
 #' \code{mt_diffmap} creates a difference-heatmap of the trajectory data using
 #' gaussian smoothing. Note that this function has beta status.
 #' 
+#' @details 
+#' 
 #' \code{mt_diffmap} takes two objects that either contain trajectory heatmaps
 #' or from which trajectory heatmaps can be computed. Difference-heatmaps are
 #' constructed analogously to \link{mt_heatmap_raw}.  
